@@ -39,6 +39,7 @@ from ..profile import (RepositoryStorageSet, DEFAULT_BRANCH,
 
 from calculate.lib.variables import linux as lib_linux
 from calculate.lib.variables import env
+from calculate.lib.variables import system as lib_system
 from calculate.update.update_info import UpdateInfo
 from itertools import chain
 from urlparse import urlparse
@@ -240,6 +241,14 @@ class VariableClUpdateBranch(Variable):
     не используется синхронизация по тэгам
     """
     value = Git.Reference.Master
+    arch_var = "main.os_arch_machine"
+
+    def get(self):
+        arch = self.Get(self.arch_var)
+        if arch == "x86_64":
+            return "master64"
+        else:
+            return "master"
 
 
 class VariableClUpdateBranchData(TableVariable):
@@ -1013,12 +1022,19 @@ class VariableClUpdateProfileBranch(Variable):
 
     storage = "cl_update_profile_storage"
     url = "cl_update_profile_url"
-    value = DEFAULT_BRANCH
 
     def init(self):
         self.label = _("Repository branch")
         self.help = _("set the repository branch")
 
+    def get(self):
+        arch = self.Get("main.os_arch_machine")
+        if arch == "x86_64":
+            print "MASTER64"
+            return "master64"
+        else:
+            return "master"
+
 
 class VariableClProfileRepository(ReadonlyVariable):
     """
@@ -1260,6 +1276,7 @@ class DataVarsUpdateProfile(SimpleDataVars):
             lib_linux.VariableOsLinuxSubname(),
             lib_linux.VariableOsLinuxVer(),
             lib_linux.VariableClProfileSystem(),
+            lib_system.VariableOsArchMachine(),
             env.VariableClRepositoryData(),
             env.VariableClRepositoryName(),
             env.VariableClRepositoryLocation(),
